@@ -1,6 +1,6 @@
 import numpy as np
 import argparse
-from seispy.rfcorrect import SACStation
+from seispy.rfcorrect import RFStation
 from seispy.ccp3d import CCP3D
 from seispy.ccpprofile import CCPProfile
 from scipy.interpolate import interp1d
@@ -9,6 +9,25 @@ from seispy.rf import RF
 from seispy.recalrf import ReRF
 
 
+def rfharmo():
+    parser = argparse.ArgumentParser('Harmonic decomposition for extracting anisotropic and isotropic features from the radial and transverse RFs')
+    parser.add_argument('rfpath', type=str, help="Path to PRFs")
+    parser.add_argument('-t', help="Time window from tb to te for triming RFs, NOTE: do not insert space before this argument, defaults to -2/10",
+                        metavar='tb/te', default='-2/10')
+    parser.add_argument('-s', help="Resample RFs with sampling interval of dt", metavar='dt', default=None, type=float)
+    parser.add_argument('-o', help="Specify output path for saving constant component.", metavar='outpath', default=None, type=str)
+    parser.add_argument('-p', help='Figure output path, defaults to ./', metavar='figure_path', default='./', type=str)
+    args = parser.parse_args()
+    rfsta = RFStation(args.rfpath)
+    if args.s is not None:
+        rfsta.resample(args.s)
+    twin = [float(v) for v in args.t.split('/')]
+    rfsta.harmonic(twin[0], twin[1])
+    if args.o is not None:
+        rfsta.harmo.write_constant(args.o)
+    rfsta.harmo.plot(outpath=args.p)
+
+
 def rfani():
     parser = argparse.ArgumentParser(description="Estimate crustal anisotropy with a Joint inversion method. See Liu and Niu (2012) in detail.")
     parser.add_argument('rfpath', type=str, help="Path to PRFs")
@@ -31,7 +50,7 @@ def rfani():
     arg = parser.parse_args()
     weights = np.array(arg.weight.split('/')).astype(float)
     timewin = np.array(arg.t.split('/')).astype(float)
-    rfsta = SACStation(arg.rfpath)
+    rfsta = RFStation(arg.rfpath)
     bf, bt = rfsta.jointani(timewin[0], timewin[1], tlen=arg.l, weight=weights)
     with open(arg.c, 'a+') as fid:
         fid.write('{}\t{:.3f}\t{:.3f}\t{:.2f}\t{:.2f}\t{:.2f}\t{:.2f}\n'.format(
@@ -81,7 +100,7 @@ def get_pierce_points():
     arg = parser.parse_args()
     rfdep = read_rfdep(arg.rfdepth_path)
     if arg.d > rfdep[0]['depthrange'][-1]:
-        raise ValueError('The depth exceed max depth in {}'.format(arg.rfdepth_path))
+        parser.error('The depth exceed max depth in {}'.format(arg.rfdepth_path))
     with open(arg.o, 'w') as f:
         for sta in rfdep:
             for i in range(sta['piercelat'].shape[0]):
@@ -167,8 +186,10 @@ def srf():
     parser = common_parser()
     parser.add_argument('-p', help='Wether or not manually pick arrival time and waveforms arround S phase with a GUI.',
                         action='store_true')
+    parser.add_argument('-i', help='Wether grid search incidence angle',
+                        action='store_true')
     arg = parser.parse_args()
-    pjt = RF(cfg_file=arg.cfg_file, phase='S')
+    pjt = RF(cfg_file=arg.cfg_file)
 
     pjt.para.switchEN = arg.isswitch
     pjt.para.reverseE ,pjt.para.reverseN= parse_common_args(arg)
@@ -186,7 +207,7 @@ def srf():
         pjt.baz_correct()
     else:
         pass
-    pjt.rotate()
+    pjt.rotate(search_inc=arg.i)
     if arg.p:
         pjt.pick()
     if arg.w:
